summaryrefslogtreecommitdiffstats
path: root/ui/compositor/compositing_recorder.h
diff options
context:
space:
mode:
authorwkorman <wkorman@chromium.org>2015-12-04 02:55:26 -0800
committerCommit bot <commit-bot@chromium.org>2015-12-04 10:56:12 +0000
commit8dd1b27b85bedbcd8b4890732fac27389ad67744 (patch)
treeeae66f10206fe348dc35f00dbe236975571b63b9 /ui/compositor/compositing_recorder.h
parent79a9c7f80d3059e696b8c8dd0e00546f3fa6edf8 (diff)
downloadchromium_src-8dd1b27b85bedbcd8b4890732fac27389ad67744.zip
chromium_src-8dd1b27b85bedbcd8b4890732fac27389ad67744.tar.gz
chromium_src-8dd1b27b85bedbcd8b4890732fac27389ad67744.tar.bz2
Improve clip path visual rect. Clean up clip/transform recorder ctor.
BUG=529938 Review URL: https://codereview.chromium.org/1490423002 Cr-Commit-Position: refs/heads/master@{#363183}
Diffstat (limited to 'ui/compositor/compositing_recorder.h')
-rw-r--r--ui/compositor/compositing_recorder.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/compositor/compositing_recorder.h b/ui/compositor/compositing_recorder.h
index 499f424..e50f692 100644
--- a/ui/compositor/compositing_recorder.h
+++ b/ui/compositor/compositing_recorder.h
@@ -25,10 +25,10 @@ class PaintContext;
class COMPOSITOR_EXPORT CompositingRecorder {
public:
// |alpha| is a value between 0 and 255, where 0 is transparent and 255 is
// opaque. |size_in_layer| is the size in layer space dimensions surrounding
// everything that's visible.
CompositingRecorder(const PaintContext& context,
- const gfx::Size& size_in_layer,
+ const gfx::Size& size_in_context,
uint8_t alpha);
~CompositingRecorder();
@@ -25,10 +25,10 @@ class PaintContext;
public:
// |alpha| is a value between 0 and 255, where 0 is transparent and 255 is
- // opaque. |size_in_layer| is the size in layer space dimensions surrounding
+ // opaque. |size_in_context| is the size in the |context|'s space surrounding
// everything that's visible.
CompositingRecorder(const PaintContext& context,